# __main__.py

import sys

from phel import feed, viewer


def main():
    """Read the Real Python article feed"""

    # If an article ID is given, then show the article
    if len(sys.argv) > 1:
        article = feed.get_article(sys.argv[1])
        viewer.show(article)

    # If no ID is given, then show a list of all articles
    else:
        site = feed.get_site()
        titles = feed.get_titles()
        viewer.show_list(site, titles)


if __name__ == "__main__":
    main()



# feed.py

# from functools import cache
from functools import lru_cache
import feedparser
import html2text

import phel


@lru_cache(maxsize=None)
def _get_feed(url=phel.URL):
    """Read the web feed, use caching to only read it once"""
    return feedparser.parse(url)


def get_site(url=phel.URL):
    """Get name and link to website of the feed"""
    feed = _get_feed(url).feed
    return f"{feed.title} ({feed.link})"


def get_titles(url=phel.URL):
    """List titles in the feed"""
    articles = _get_feed(url).entries
    return [a.title for a in articles]


def get_article(article_id, url=phel.URL):
    """Get article from feed with the given ID"""
    articles = _get_feed(url).entries
    article = articles[int(article_id)]
    html = article.content[0].value
    text = html2text.html2text(html)
    return f"# {article.title}\n\n{text}"
